@@ -6,6 +6,11 @@ function runProcDumpAndValidate {
 	dumpDir=$(mktemp -d -t dump_XXXXXX)
 	cd $dumpDir
 
+	dumpParam=""
+	if [ "$#" -ge "6" -a -n "$6" ]; then
+		dumpParam="-o $dumpDir/$6"
+	fi
+
 	if [ -z "$TESTPROGNAME" ]; then
 		if [ "$5" == "MEM" ]; then
 			stress-ng --vm 1 --vm-hang 0 --vm-bytes $1 --timeout 20s -q&
@@ -17,22 +22,22 @@ function runProcDumpAndValidate {
 
 		sleep 1s
 
-		childrenpid=$(pidof -o $pid stress-ng)
+		childrenpid=$(pidof -o $pid $(which stress-ng))
 			echo "ChildrenPID: $childrenpid"
 
 		childpid=$(echo $childrenpid | cut -d " " -f1)
 		echo "ChildPID: $childpid"
 
-		echo "$PROCDUMPPATH $2 $3 -p $childpid"
-		$PROCDUMPPATH $2 $3 -p $childpid
+		echo "$PROCDUMPPATH $2 $3 $dumpParam -p $childpid"
+		$PROCDUMPPATH $2 $3 $dumpParam -p $childpid
 	else
 		TESTPROGPATH=$(readlink -m "$DIR/../../bin/$TESTPROGNAME");
 		(sleep 2; $TESTPROGPATH "$TESTPROGMODE") &
 		pid=$!
 		echo "PID: $pid"
 
-		echo "$PROCDUMPPATH $2 $3 -w $TESTPROGNAME"
-		$PROCDUMPPATH $2 $3 -w "$TESTPROGNAME"
+		echo "$PROCDUMPPATH $2 $3 $dumpParam -w $TESTPROGNAME"
+		$PROCDUMPPATH $2 $3 $dumpParam -w "$TESTPROGNAME"
 	fi
 
 	if ps -p $pid > /dev/null
