@@ -8,4 +8,4 @@ procDumpType="-C"
 procDumpTrigger=80
 shouldDump=false
 
-runProcDumpAndValidate $stressPercentage $procDumpType $procDumpTrigger $shouldDump
+runProcDumpAndValidate $stressPercentage $procDumpType $procDumpTrigger $shouldDump "CPU"
