@@ -10,4 +10,4 @@ procDumpType="-c"
 procDumpTrigger=20
 shouldDump=true
 
-runProcDumpAndValidate $stressPercentage $procDumpType $procDumpTrigger $shouldDump
+runProcDumpAndValidate $stressPercentage $procDumpType $procDumpTrigger $shouldDump "CPU"
